#include "main.ih"

namespace
{
    ArgConfig::LongOption longOpts[] =
    {
        {"add-root",            ArgConfig::Required},
        {"all",                 'a'},
        {"block-size",          'b'},
        {"config-file",         'c'},
        {"directories",         ArgConfig::Required},
        {"generalized-search",  'g'},
        {"help",                'h'},
        {"input",               ArgConfig::None},
        {"history",             ArgConfig::Optional},
        {"history-lifetime",    ArgConfig::Required},
        {"history-maxsize",     ArgConfig::Required},   // history/load.cc
        {"history-position",    ArgConfig::Required},   // top, bottom
        {"history-separate",    ArgConfig::None},
        {"homedir-char",        ArgConfig::Required},
        {"icase",               'i'},
        {"start-at",            ArgConfig::Required},
        {"traditional",         ArgConfig::None},
        {"verbose",             'V'},
        {"version",             'v'},
    };
    auto longEnd = longOpts + size(longOpts);
}

int main(int argc, char **argv)
try
{
    Options::initialize("ab:c:gihvV", longOpts, longEnd, argc, argv,
                        Icmbuild::version, usage);

    Alternatives alternatives;
                                        // select viable alternatives
    if (alternatives.viable() == Alternatives::ONLY_CD)
        return 0;

    alternatives.order();               // history alternatives first or last

    Selector selector(alternatives);

    selector.select();                   // make the selection

    return selector.decided() ? 0 : 1;  // return 0 to the OS if the selector
                                        // did do its work
}
catch(...)
{
    return handle(current_exception());
}

